@@ -1,32 +1,26 @@
-import sys
+from typing import List, Type
 
+import six
+from django.contrib.auth.models import User
 from django.db import models
-from django.db.models import ForeignKey, OneToOneField, ManyToManyField
+from django.db.models import ForeignKey, ManyToManyField, OneToOneField
 from django.db.models.fields.related import ForeignObjectRel as RelatedObject
 
-# taking a nod from python-requests and skipping six
-_ver = sys.version_info
-is_py2 = (_ver[0] == 2)
-is_py3 = (_ver[0] == 3)
-basestring = None
-unicode = None
+from drip.types import FieldType
 
-if is_py2:
-    basestring = basestring
-    unicode = unicode
-elif is_py3:
-    basestring = (str, bytes)
-    unicode = str
+basestring = (str, bytes)
+unicode = str
 
 
-def check_redundant(model_stack: list, stack_limit: int) -> bool:
-    """[summary]
+def check_redundant(model_stack: List[Type[models.Model]], stack_limit: int) -> bool:
+    """
+    Checks to ensure recursion isnt being redundant
 
-    :param model_stack: [description]
-    :type model_stack: list
-    :param stack_limit: [description]
+    :param model_stack: List of models.Model
+    :type model_stack: List[Type[models.Model]]
+    :param stack_limit: recursion depth to check redundancy
     :type stack_limit: int
-    :return: [description]
+    :return: Bool that controls if stops recursion
     :rtype: bool
     """
     stop_recursion = False
@@ -35,9 +29,9 @@ def check_redundant(model_stack: list, stack_limit: int) -> bool:
         # stack depth shouldn't exceed x, or
         # we've hit a point where we are repeating models
         if (
-            (model_stack[-3] == model_stack[-1]) or
-            (len(model_stack) > 5) or
-            (len(set(model_stack)) != len(model_stack))
+            (model_stack[-3] == model_stack[-1])
+            or (len(model_stack) > 5)
+            or (len(set(model_stack)) != len(model_stack))
         ):
             stop_recursion = True
     return stop_recursion
@@ -52,13 +46,12 @@ def get_field_name(field, RelatedObject):
 
 
 def get_full_field(parent_field: str, field_name: str) -> str:
-    """[summary]
-
-    :param parent_field: [description]
+    """
+    :param parent_field: Name of parent field
     :type parent_field: str
-    :param field_name: [description]
+    :param field_name: Field name
     :type field_name: str
-    :return: [description]
+    :return: It is the join between parent_field and field_name or just the field_name
     :rtype: str
     """
     if parent_field:
@@ -68,25 +61,31 @@ def get_full_field(parent_field: str, field_name: str) -> str:
     return full_field
 
 
-def get_rel_model(field, RelatedObject):
-    if isinstance(field, RelatedObject):
+def get_rel_model(field: FieldType, RelatedObject: RelatedObject) -> Type[models.Model]:
+    if isinstance(field, RelatedObject):  # type: ignore
         RelModel = field.model
         # field_names.extend(get_fields(RelModel, full_field, True))
     else:
-        RelModel = field.related_model
-    return RelModel
+        RelModel = field.related_model  # type: ignore
+    return RelModel  # type: ignore
 
 
-def is_valid_instance(field):
+def is_valid_instance(field: FieldType) -> bool:
     return (
-        isinstance(field, ForeignKey) or
-        isinstance(field, OneToOneField) or
-        isinstance(field, RelatedObject) or
-        isinstance(field, ManyToManyField)
+        isinstance(field, ForeignKey)
+        or isinstance(field, OneToOneField)
+        or isinstance(field, RelatedObject)
+        or isinstance(field, ManyToManyField)
     )
 
 
-def get_out_fields(Model, parent_field, model_stack, excludes, fields):
+def get_out_fields(
+    Model: Type[models.Model],
+    parent_field: str,
+    model_stack: List[Type[models.Model]],
+    excludes: List[str],
+    fields: List[FieldType],
+):
     out_fields = []
     for field in fields:
 
@@ -102,7 +101,7 @@ def get_out_fields(Model, parent_field, model_stack, excludes, fields):
 
         if is_valid_instance(field):
 
-            RelModel = get_rel_model(field, RelatedObject)
+            RelModel = get_rel_model(field, RelatedObject)  # type: ignore
 
             out_fields.extend(
                 get_fields(RelModel, full_field, list(model_stack)),
@@ -112,11 +111,11 @@ def get_out_fields(Model, parent_field, model_stack, excludes, fields):
 
 
 def get_fields(
-    Model,
-    parent_field="",
-    model_stack=[],
-    stack_limit=2,
-    excludes=['permissions', 'comment', 'content_type']
+    Model: Type[models.Model],
+    parent_field: str = "",
+    model_stack: List[Type[models.Model]] = [],
+    stack_limit: int = 2,
+    excludes: List[str] = ["permissions", "comment", "content_type"],
 ):
     """
     Given a Model, return a list of lists of strings with important stuff:
@@ -126,16 +125,14 @@ def get_fields(
     ['test_user__confirmed', 'confirmed', 'TestUser', 'BooleanField']
     ...
 
-     """
+    """
 
     # github.com/omab/python-social-auth/commit/d8637cec02422374e4102231488481170dc51057
-    if isinstance(Model, basestring):
-        app_label, model_name = Model.split('.')
-        Model = models.get_model(app_label, model_name)
+    if isinstance(Model, six.string_types):
+        app_label, model_name = Model.split(".")
+        Model = models.get_model(app_label, model_name)  # type: ignore
 
-    fields = Model._meta.fields + \
-        Model._meta.many_to_many + \
-        Model._meta.get_fields()
+    fields = Model._meta.fields + Model._meta.many_to_many + Model._meta.get_fields()  # type: ignore
     model_stack.append(Model)
 
     # do a variety of checks to ensure recursion isnt being redundant
@@ -148,54 +145,53 @@ def get_fields(
     return get_out_fields(Model, parent_field, model_stack, excludes, fields)
 
 
-def give_model_field(full_field: str, Model: models.Model) -> tuple:
+def give_model_field(full_field: str, Model: Type[models.Model]) -> tuple:
     """Given a field_name and Model:
 
     "test_user__unique_id", <AchievedGoal>
 
     Returns "test_user__unique_id", "id", <Model>, <ModelField>
 
-    :param full_field: [description]
+    :param full_field: full field name
     :type full_field: str
-    :param Model: [description]
+    :param Model: models.Model
     :type Model: models.Model
-    :raises Exception: [description]
-    :return: [description]
+    :raises Exception: If the key is not found it raises and exception
+    :return: It is a tuple with field full name, field name, <Model>, <ModelField>
     :rtype: tuple
     """
 
-    field_data = get_fields(Model, '', [])
+    field_data = get_fields(Model, "", [])
 
     for full_key, name, _Model, _ModelField in field_data:
         if full_key == full_field:
             return full_key, name, _Model, _ModelField
-
-    raise Exception(
-        'Field key `{field}` not found on `{model}`.'.format(
-            field=full_field,
-            model=Model.__name__
-        )
+    message_exception = "Field key `{field}` not found on `{model}`.".format(
+        field=full_field,
+        model=Model.__name__,  # type: ignore
     )
+    raise Exception(message_exception)
 
 
-def get_simple_fields(Model, **kwargs):
-    ret_list = []
+def get_simple_fields(Model: Type[models.Model], **kwargs) -> List:
+    ret_list: List = []
     for f in get_fields(Model, **kwargs):
-        if '__' in f[0]:
+        if "__" in f[0]:
             # Add __user__ to the fields in related models
-            parts = f[0].split('__')
-            f[0] = parts[0] + '__user__' + parts[1]
+            parts = f[0].split("__")
+            f[0] = parts[0] + "__user__" + parts[1]
         if f[0] not in [x[0] for x in ret_list]:
             # Add field if not already in list
             ret_list.append([f[0], f[3].__name__])
     return ret_list
 
 
-def get_user_model():
+def get_user_model() -> Type[User]:
     # handle 1.7 and back
     try:
         from django.contrib.auth import get_user_model as django_get_user_model
+
         User = django_get_user_model()
     except ImportError:
-        from django.contrib.auth.models import User
+        pass
     return User
